import { CreateContactRequest as CreateContactRequest$1, CreateContactResponse as CreateContactResponse$1, UpdateContactRequest as UpdateContactRequest$1, UpdateContactResponse as UpdateContactResponse$1, MergeContactsRequest as MergeContactsRequest$1, MergeContactsResponse as MergeContactsResponse$1, DeleteContactRequest as DeleteContactRequest$1, DeleteContactResponse as DeleteContactResponse$1, LabelContactRequest as LabelContactRequest$1, LabelContactResponse as LabelContactResponse$1, UnlabelContactRequest as UnlabelContactRequest$1, UnlabelContactResponse as UnlabelContactResponse$1, QueryContactsRequest as QueryContactsRequest$1, QueryContactsResponse as QueryContactsResponse$1, GetContactRequest as GetContactRequest$1, GetContactResponse as GetContactResponse$1 } from './index.typings.mjs';
import '@wix/sdk-types';

interface Contact {
    /**
     * Contact ID.
     * @format GUID
     * @readonly
     */
    id?: string;
    /**
     * Revision number, which increments by 1 each time the contact is updated.
     * To prevent conflicting changes,
     * the existing `revision` must be specified when updating a contact.
     * @readonly
     */
    revision?: number;
    /**
     * Details about the contact's source.
     * @readonly
     */
    source?: ContactSource;
    /**
     * Date and time the contact was created.
     * @readonly
     */
    createdDate?: Date | null;
    /**
     * Date and time the contact was last updated.
     * @readonly
     */
    updatedDate?: Date | null;
    /**
     * Details about the contact's last action in the site.
     * @readonly
     */
    lastActivity?: ContactActivity;
    /**
     * Contact's primary phone and email.
     * @readonly
     */
    primaryInfo?: PrimaryContactInfo;
    /** Contact's details. */
    info?: ContactInfo;
    /**
     * Contact's primary email details.
     * @readonly
     */
    primaryEmail?: PrimaryEmail;
    /**
     * Contact's primary phone details.
     * @readonly
     */
    primaryPhone?: PrimaryPhone;
}
interface ContactSource {
    /**
     * Source type.
     * @readonly
     */
    sourceType?: ContactSourceTypeWithLiterals;
    /**
     * App ID, if the contact was created by an app.
     * @format GUID
     * @readonly
     */
    appId?: string | null;
}
declare enum ContactSourceType {
    OTHER = "OTHER",
    ADMIN = "ADMIN",
    WIX_APP = "WIX_APP",
    IMPORT = "IMPORT",
    THIRD_PARTY = "THIRD_PARTY",
    WIX_BOOKINGS = "WIX_BOOKINGS",
    WIX_CHAT = "WIX_CHAT",
    WIX_EMAIL_MARKETING = "WIX_EMAIL_MARKETING",
    WIX_EVENTS = "WIX_EVENTS",
    WIX_FORMS = "WIX_FORMS",
    WIX_GROUPS = "WIX_GROUPS",
    WIX_HOTELS = "WIX_HOTELS",
    WIX_MARKET_PLACE = "WIX_MARKET_PLACE",
    WIX_MUSIC = "WIX_MUSIC",
    WIX_RESTAURANTS = "WIX_RESTAURANTS",
    WIX_SITE_MEMBERS = "WIX_SITE_MEMBERS",
    WIX_STORES = "WIX_STORES",
    WIX_CODE = "WIX_CODE",
    HOPP = "HOPP"
}
/** @enumType */
type ContactSourceTypeWithLiterals = ContactSourceType | 'OTHER' | 'ADMIN' | 'WIX_APP' | 'IMPORT' | 'THIRD_PARTY' | 'WIX_BOOKINGS' | 'WIX_CHAT' | 'WIX_EMAIL_MARKETING' | 'WIX_EVENTS' | 'WIX_FORMS' | 'WIX_GROUPS' | 'WIX_HOTELS' | 'WIX_MARKET_PLACE' | 'WIX_MUSIC' | 'WIX_RESTAURANTS' | 'WIX_SITE_MEMBERS' | 'WIX_STORES' | 'WIX_CODE' | 'HOPP';
interface ContactActivity {
    /** Date and time of the last action. */
    activityDate?: Date | null;
    /** Contact's last action in the site. */
    activityType?: ContactActivityTypeWithLiterals;
}
declare enum ContactActivityType {
    /** Visited the site. */
    GENERAL = "GENERAL",
    /** Became a new contact. */
    CONTACT_CREATED = "CONTACT_CREATED",
    /** Logged in. */
    MEMBER_LOGIN = "MEMBER_LOGIN",
    /** Requested a site membership. */
    MEMBER_REGISTER = "MEMBER_REGISTER",
    /** Was approved, blocked, or unblocked. */
    MEMBER_STATUS_CHANGED = "MEMBER_STATUS_CHANGED",
    /** Submitted a form. */
    FORM_SUBMITTED = "FORM_SUBMITTED",
    /** Started a chat. */
    INBOX_FORM_SUBMITTED = "INBOX_FORM_SUBMITTED",
    /** Paid a payment request. */
    INBOX_PAYMENT_REQUEST_PAID = "INBOX_PAYMENT_REQUEST_PAID",
    /** Received a message from the site. */
    INBOX_MESSAGE_TO_CUSTOMER = "INBOX_MESSAGE_TO_CUSTOMER",
    /** Sent a new message to the site. */
    INBOX_MESSAGE_FROM_CUSTOMER = "INBOX_MESSAGE_FROM_CUSTOMER",
    /** Subscribed to a site newsletter through a form. */
    NEWSLETTER_SUBSCRIPTION_FORM_SUBMITTED = "NEWSLETTER_SUBSCRIPTION_FORM_SUBMITTED",
    /** Unsubscribed from a site newsletter. */
    NEWSLETTER_SUBSCRIPTION_UNSUBSCRIBE = "NEWSLETTER_SUBSCRIPTION_UNSUBSCRIBE",
    /** Made a purchase. */
    ECOM_PURCHASE = "ECOM_PURCHASE",
    /** Abandoned a shopping cart. */
    ECOM_CART_ABANDON = "ECOM_CART_ABANDON",
    /** Checked out shopping cart and submitted buyer info (but didn’t complete the purchase yet). */
    ECOM_CHECKOUT_BUYER = "ECOM_CHECKOUT_BUYER",
    /** Booked an appointment. */
    BOOKINGS_APPOINTMENT = "BOOKINGS_APPOINTMENT",
    /** Made a Wix Hotels reservation. */
    HOTELS_RESERVATION = "HOTELS_RESERVATION",
    /** Paid for a Wix Hotels reservation. */
    HOTELS_PURCHASE = "HOTELS_PURCHASE",
    /** Confirmed a Wix Hotels reservation. */
    HOTELS_CONFIRMATION = "HOTELS_CONFIRMATION",
    /** Canceled a Wix Hotels reservation. */
    HOTELS_CANCEL = "HOTELS_CANCEL",
    /** Purchased a video. */
    VIDEO_PURCHASE = "VIDEO_PURCHASE",
    /** Rented a video. */
    VIDEO_RENT = "VIDEO_RENT",
    /** Made a purchase with a pay button. */
    CASHIER_BUTTON_PURCHASE = "CASHIER_BUTTON_PURCHASE",
    /** Became a new Wix Marketplace lead. */
    ARENA_NEW_LEAD = "ARENA_NEW_LEAD",
    /** RSVP'd to an event. */
    EVENTS_RSVP = "EVENTS_RSVP",
    /** Paid an invoice. */
    INVOICE_PAY = "INVOICE_PAY",
    /** An invoice is now overdue. */
    INVOICE_OVERDUE = "INVOICE_OVERDUE",
    /** Accepted a price quote. */
    PRICE_QUOTE_ACCEPT = "PRICE_QUOTE_ACCEPT",
    /** A price quote has expired. */
    PRICE_QUOTE_EXPIRE = "PRICE_QUOTE_EXPIRE",
    /** Ordered food with Wix Restaurants. */
    RESTAURANTS_ORDER = "RESTAURANTS_ORDER",
    /** Made a Wix Restaurants reservation. */
    RESTAURANTS_RESERVATION = "RESTAURANTS_RESERVATION",
    /** Opened an email from the site. */
    SHOUTOUT_OPEN = "SHOUTOUT_OPEN",
    /** Clicked a link in an email from the site. */
    SHOUTOUT_CLICK = "SHOUTOUT_CLICK",
    /** Merged with another contact. */
    CONTACT_MERGED = "CONTACT_MERGED",
    /** Subscribed to a site newsletter. */
    NEWSLETTER_SUBSCRIPTION_SUBSCRIBE = "NEWSLETTER_SUBSCRIPTION_SUBSCRIBE",
    /** Subscription status to site newsletters is pending confirmation. */
    NEWSLETTER_SUBSCRIPTION_PENDING = "NEWSLETTER_SUBSCRIPTION_PENDING",
    /** Subscription status to site newsletters is not set. */
    NEWSLETTER_SUBSCRIPTION_NOT_SET = "NEWSLETTER_SUBSCRIPTION_NOT_SET",
    /** Subscribed to phone notifications. */
    PHONE_SUBSCRIPTION_SUBSCRIBE = "PHONE_SUBSCRIPTION_SUBSCRIBE",
    /** Subscription to phone notificatons is pending confirmation. */
    PHONE_SUBSCRIPTION_PENDING = "PHONE_SUBSCRIPTION_PENDING",
    /** Subscription to phone notificatons is not set. */
    PHONE_SUBSCRIPTION_NOT_SET = "PHONE_SUBSCRIPTION_NOT_SET",
    /** Subscribed to phone notifications. */
    PHONE_SUBSCRIPTION_UNSUBSCRIBE = "PHONE_SUBSCRIPTION_UNSUBSCRIBE"
}
/** @enumType */
type ContactActivityTypeWithLiterals = ContactActivityType | 'GENERAL' | 'CONTACT_CREATED' | 'MEMBER_LOGIN' | 'MEMBER_REGISTER' | 'MEMBER_STATUS_CHANGED' | 'FORM_SUBMITTED' | 'INBOX_FORM_SUBMITTED' | 'INBOX_PAYMENT_REQUEST_PAID' | 'INBOX_MESSAGE_TO_CUSTOMER' | 'INBOX_MESSAGE_FROM_CUSTOMER' | 'NEWSLETTER_SUBSCRIPTION_FORM_SUBMITTED' | 'NEWSLETTER_SUBSCRIPTION_UNSUBSCRIBE' | 'ECOM_PURCHASE' | 'ECOM_CART_ABANDON' | 'ECOM_CHECKOUT_BUYER' | 'BOOKINGS_APPOINTMENT' | 'HOTELS_RESERVATION' | 'HOTELS_PURCHASE' | 'HOTELS_CONFIRMATION' | 'HOTELS_CANCEL' | 'VIDEO_PURCHASE' | 'VIDEO_RENT' | 'CASHIER_BUTTON_PURCHASE' | 'ARENA_NEW_LEAD' | 'EVENTS_RSVP' | 'INVOICE_PAY' | 'INVOICE_OVERDUE' | 'PRICE_QUOTE_ACCEPT' | 'PRICE_QUOTE_EXPIRE' | 'RESTAURANTS_ORDER' | 'RESTAURANTS_RESERVATION' | 'SHOUTOUT_OPEN' | 'SHOUTOUT_CLICK' | 'CONTACT_MERGED' | 'NEWSLETTER_SUBSCRIPTION_SUBSCRIBE' | 'NEWSLETTER_SUBSCRIPTION_PENDING' | 'NEWSLETTER_SUBSCRIPTION_NOT_SET' | 'PHONE_SUBSCRIPTION_SUBSCRIBE' | 'PHONE_SUBSCRIPTION_PENDING' | 'PHONE_SUBSCRIPTION_NOT_SET' | 'PHONE_SUBSCRIPTION_UNSUBSCRIBE';
interface PrimaryContactInfo {
    /**
     * Primary email address.
     *
     * This property reflects the email address in `info.emails`
     * where `primary` is `true`.
     * @format EMAIL
     * @readonly
     */
    email?: string | null;
    /**
     * Primary phone number.
     *
     * This property reflects the phone number in `info.phones`
     * where `primary` is `true`.
     * @readonly
     */
    phone?: string | null;
}
interface Image {
    /**
     * WixMedia image ID.
     * This property is written by Wix when an image is uploaded to the Wix Media Manager.
     */
    id?: string;
    /** Image source: Either a Media Manager URL or external URL. */
    url?: string;
    /** Height of the original image. */
    height?: number;
    /** Width of the original image. */
    width?: number;
    /** Image alt text (optional). */
    altText?: string | null;
    /**
     * Image URL expiration date (optional).
     * @readonly
     */
    urlExpirationDate?: Date | null;
}
interface ContactInfo {
    /** Contact's first and last name. */
    name?: ContactName;
    /** Contact's email addresses. */
    emails?: ContactEmailsWrapper;
    /** Contact's phone numbers. */
    phones?: ContactPhonesWrapper;
    /** Contact's street addresses. */
    addresses?: ContactAddressesWrapper;
    /**
     * Contact's company name.
     * @maxLength 1000
     */
    company?: string | null;
    /**
     * Contact's job title.
     * @maxLength 1000
     */
    jobTitle?: string | null;
    /**
     * Birth date in `YYYY-MM-DD` format. For example, `2020-03-15`.
     * @format LOCAL_DATE
     */
    birthdate?: string | null;
    /**
     * Locale in
     * [IETF BCP 47 language tag](https://en.wikipedia.org/wiki/IETF_language_tag) format.
     * Typically, this is a lowercase 2-letter language code,
     * followed by a hyphen, followed by an uppercase 2-letter country code.
     * For example, `en-US` for U.S. English, and `de-DE` for Germany German.
     * @format LANGUAGE_TAG
     */
    locale?: string | null;
    /**
     * List of contact's labels.
     *
     * Labels are used to organize contacts. Labels can be
     * added and removed using Label Contact and Unlabel Contact, respectively.
     *
     * To view or manage contact labels, use the Labels API.
     */
    labelKeys?: LabelsWrapper;
    /**
     * Additional custom fields.
     *
     * Empty fields are not returned.
     */
    extendedFields?: ExtendedFieldsWrapper;
    /** Contact's profile picture. */
    picture?: ContactPicture;
}
interface ContactName {
    /**
     * Contact's first name.
     * @maxLength 1000
     */
    first?: string | null;
    /**
     * Contact's last name.
     * @maxLength 1000
     */
    last?: string | null;
}
interface ContactEmailsWrapper {
    /**
     * List of up to 50 email addresses.
     * @maxSize 50
     */
    items?: ContactEmail[];
}
interface ContactEmail {
    /**
     * Email ID.
     * @format GUID
     * @readonly
     */
    id?: string | null;
    /**
     * Email type.
     *
     * `UNTAGGED` is shown as "Other" in the Contact List.
     */
    tag?: EmailTagWithLiterals;
    /**
     * Email address.
     * @minLength 1
     * @maxLength 320
     */
    email?: string;
    /**
     * Indicates whether this is the contact's primary email address.
     * When changing `primary` to `true` for an email,
     * the contact's other emails become `false`.
     * Changing the primary email of a contact also affects the subscription status to marketing emails that are decided based on the primary email.
     */
    primary?: boolean | null;
}
declare enum EmailTag {
    UNTAGGED = "UNTAGGED",
    MAIN = "MAIN",
    HOME = "HOME",
    WORK = "WORK"
}
/** @enumType */
type EmailTagWithLiterals = EmailTag | 'UNTAGGED' | 'MAIN' | 'HOME' | 'WORK';
interface ContactPhonesWrapper {
    /**
     * List of up to 50 phone numbers.
     * @maxSize 50
     */
    items?: ContactPhone[];
}
interface ContactPhone {
    /**
     * Phone ID.
     * @format GUID
     * @readonly
     */
    id?: string | null;
    /**
     * Phone type.
     *
     * `UNTAGGED` is shown as "Other" in the Contact List.
     */
    tag?: PhoneTagWithLiterals;
    /**
     * [ISO-3166 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.
     * @format COUNTRY
     */
    countryCode?: string | null;
    /**
     * Phone number.
     * @minLength 1
     * @maxLength 50
     */
    phone?: string;
    /**
     * [ITU E.164-formatted](https://www.itu.int/rec/T-REC-E.164/)
     * phone number.
     * Automatically generated using `phone` and `countryCode`, pending both values are valid.
     * @readonly
     */
    e164Phone?: string | null;
    /**
     * Indicates whether this is the contact's primary phone number.
     * When changing `primary` to `true` for a phone,
     * the contact's `primary` field for other phones becomes `false`.
     * Changing the primary phone number also affects the subscription status to SMS messages that are decided based on the primary phone.
     */
    primary?: boolean | null;
}
declare enum PhoneTag {
    UNTAGGED = "UNTAGGED",
    MAIN = "MAIN",
    HOME = "HOME",
    MOBILE = "MOBILE",
    WORK = "WORK",
    FAX = "FAX"
}
/** @enumType */
type PhoneTagWithLiterals = PhoneTag | 'UNTAGGED' | 'MAIN' | 'HOME' | 'MOBILE' | 'WORK' | 'FAX';
interface ContactAddressesWrapper {
    /**
     * List of up to 50 addresses.
     * @maxSize 50
     */
    items?: ContactAddress[];
}
interface ContactAddress {
    /**
     * Street address ID.
     * @format GUID
     * @readonly
     */
    id?: string | null;
    /**
     * Address type.
     * `UNTAGGED` is shown as "Other" in the Contact List.
     */
    tag?: AddressTagWithLiterals;
    /** Street address. */
    address?: Address;
}
declare enum AddressTag {
    UNTAGGED = "UNTAGGED",
    HOME = "HOME",
    WORK = "WORK",
    BILLING = "BILLING",
    SHIPPING = "SHIPPING"
}
/** @enumType */
type AddressTagWithLiterals = AddressTag | 'UNTAGGED' | 'HOME' | 'WORK' | 'BILLING' | 'SHIPPING';
/** Physical address */
interface Address extends AddressStreetOneOf {
    /** Street address object, with number and name in separate fields. */
    streetAddress?: StreetAddress;
    /**
     * Main address line, usually street and number, as free text.
     * @maxLength 1000
     */
    addressLine?: string | null;
    /**
     * 2-letter country code in an
     * [ISO-3166 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2) format.
     * @format COUNTRY
     */
    country?: string | null;
    /**
     * Code for a subdivision (such as state, prefecture, or province) in an
     * [ISO 3166-2](https://en.wikipedia.org/wiki/ISO_3166-2) format.
     * @maxLength 100
     */
    subdivision?: string | null;
    /**
     * City name.
     * @maxLength 1000
     */
    city?: string | null;
    /**
     * Postal or zip code.
     * @maxLength 100
     */
    postalCode?: string | null;
    /**
     * Free text providing more detailed address information,
     * such as apartment, suite, or floor.
     * @maxLength 1000
     */
    addressLine2?: string | null;
}
/** @oneof */
interface AddressStreetOneOf {
    /** Street address object, with number and name in separate fields. */
    streetAddress?: StreetAddress;
    /**
     * Main address line, usually street and number, as free text.
     * @maxLength 1000
     */
    addressLine?: string | null;
}
interface StreetAddress {
    /**
     * Street number.
     * @maxLength 100
     */
    number?: string;
    /**
     * Street name.
     * @maxLength 1000
     */
    name?: string;
}
interface LabelsWrapper {
    /**
     * List of contact label keys.
     *
     * Contact labels help categorize contacts. Label keys must exist to be added to the contact.
     * Contact labels can be created or retrieved with Find or Create Label or List Labels.
     * @maxSize 2000
     */
    items?: string[];
}
interface ExtendedFieldsWrapper {
    /**
     * Contact's extended fields,
     * where each key is the field key,
     * and each value is the field's value for the contact.
     *
     * To view and manage extended fields, use the Extended Fields API.
     */
    items?: Record<string, any>;
}
/** TEST contact picture description */
interface ContactPicture {
    /**
     * Image.
     * This can contain an image URL or a Wix Media image ID.
     */
    image?: Image;
}
interface PrimaryEmail {
    /**
     * Primary email address.
     *
     * This field reflects the email address in `info.emails`
     * where `primary` is `true`.
     * @format EMAIL
     * @readonly
     */
    email?: string | null;
    /**
     * Indicates the recipient's opt-in or opt-out status for marketing emails.
     *
     * Default: `NOT_SET`
     * @readonly
     */
    subscriptionStatus?: SubscriptionStatusWithLiterals;
    /**
     * Indicates last reported status of sent emails.
     *
     * Default: `NOT_SET`
     * @readonly
     */
    deliverabilityStatus?: EmailDeliverabilityStatusWithLiterals;
}
declare enum SubscriptionStatus {
    /** No status exists. */
    NO_SUBSCRIPTION_STATUS = "NO_SUBSCRIPTION_STATUS",
    /** No status specified. */
    NOT_SET = "NOT_SET",
    /** Subscription confirmation was requested, but recipient hasn't confirmed yet. */
    PENDING = "PENDING",
    /** Recipient has opted in to marketing emails or SMS messages. */
    SUBSCRIBED = "SUBSCRIBED",
    /** Recipient has opted out of marketing emails or SMS messages. */
    UNSUBSCRIBED = "UNSUBSCRIBED"
}
/** @enumType */
type SubscriptionStatusWithLiterals = SubscriptionStatus | 'NO_SUBSCRIPTION_STATUS' | 'NOT_SET' | 'PENDING' | 'SUBSCRIBED' | 'UNSUBSCRIBED';
declare enum EmailDeliverabilityStatus {
    /** No status reported. */
    NOT_SET = "NOT_SET",
    /** Emails are being successfully delivered. */
    VALID = "VALID",
    /** The last email to the recipient bounced or was rejected. */
    BOUNCED = "BOUNCED",
    /** Recipient registered a spam complaint with their email provider. */
    SPAM_COMPLAINT = "SPAM_COMPLAINT",
    /** Multiple emails have been delivered without any kind of engagement from the recipient. */
    INACTIVE = "INACTIVE"
}
/** @enumType */
type EmailDeliverabilityStatusWithLiterals = EmailDeliverabilityStatus | 'NOT_SET' | 'VALID' | 'BOUNCED' | 'SPAM_COMPLAINT' | 'INACTIVE';
interface PrimaryPhone {
    /**
     * Country code of the primary phone number in [ISO-3166 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2) format.
     * @format COUNTRY
     */
    countryCode?: string | null;
    /**
     * Phone number in [ITU E.164](https://www.itu.int/rec/T-REC-E.164/) format.
     * Automatically generated using `phone` and `countryCode` when both values are valid.
     * @readonly
     */
    e164Phone?: string | null;
    /**
     * Formatted phone. Automatically generated using `phone` and `countryCode`.
     * @readonly
     */
    formattedPhone?: string | null;
    /**
     * Indicates the recipient's opt-in or opt-out status for SMS messages.
     *
     * Default:
     * - `NOT_SET` when the phone is a valid E164 phone.
     * - `NO_SUBSCRIPTION_STATUS` when the phone is not a valid E164 phone.
     * @readonly
     */
    subscriptionStatus?: SubscriptionStatusWithLiterals;
    /**
     * Primary phone number.
     *
     * This field reflects the phone number in `info.phones`
     * where `primary` is `true`.
     * @readonly
     */
    phone?: string | null;
}
/** Contact creation options. */
interface CreateContactRequest {
    /** Contact info. */
    info: ContactInfo;
    /**
     * Controls whether the call will succeed
     * if the new contact information contains an email or a phone number already used by another contact.
     *
     * If set to `true`,
     * the call will succeed even if an email address or phone number is used by another contact.
     * If set to `false`,
     * the call will fail if the given email address is used by another contact or,
     * if the email address is not given and the given phone number is used by another contact.
     *
     * Default: `false`
     */
    allowDuplicates?: boolean;
}
/** Contact. */
interface CreateContactResponse {
    /** Contact. */
    contact?: Contact;
}
interface UpdateContactRequest {
    /**
     * ID of the contact to update.
     * @format GUID
     */
    contactId: string;
    /**
     * Revision number.
     * When updating, include the existing `revision`
     * to prevent conflicting updates.
     */
    revision: number | null;
    /**
     * Controls whether the call will succeed
     * if the new contact information contains an email or a phone number already used by another contact.
     *
     * If set to `true`,
     * the call will succeed even if an email address or phone number is used by another contact.
     * If set to `false`,
     * the call will fail if the given email address is used by another contact or,
     * if the email address is not given and the given phone number is used by another contact.
     *
     * Default: `false`
     */
    allowDuplicates?: boolean;
    /** Contact info. */
    info: ContactInfo;
}
/** Updated contact. */
interface UpdateContactResponse {
    /** Updated contact. */
    contact?: Contact;
}
interface MergeContactsRequest {
    /**
     * Target contact ID.
     * @format GUID
     */
    targetContactId: string;
    /**
     * Target contact revision number, which increments by 1 each time the contact is updated.
     * To prevent conflicting changes,
     * the target contact's current `revision` must be specified.
     */
    targetContactRevision: number | null;
    /**
     * IDs of up to 5 contacts to merge into the target contact.
     * When you merge more than one source contact,
     * the first source is given precedence, then the second, and so on.
     * @minSize 1
     * @maxSize 5
     */
    sourceContactIds?: string[];
}
interface MergeContactsResponse {
    /** Updated target contact. */
    contact?: Contact;
}
interface DeleteContactRequest {
    /**
     * ID of the contact to delete.
     * @format GUID
     */
    contactId: string;
}
interface DeleteContactResponse {
}
interface LabelContactRequest {
    /**
     * ID of the contact to add labels to.
     * @format GUID
     */
    contactId: string;
    /**
     * List of label keys to add to the contact.
     *
     * Label keys must exist to be added to the contact.
     * Use the Labels API to create or retrieve labels.
     * @minSize 1
     * @maxSize 100
     */
    labelKeys: string[];
}
/** Updated contact. */
interface LabelContactResponse {
    /** Updated contact. */
    contact?: Contact;
}
interface UnlabelContactRequest {
    /**
     * ID of the contact to remove labels from.
     * @format GUID
     */
    contactId: string;
    /**
     * List of label keys to remove from the contact.
     * @minSize 1
     * @maxSize 100
     */
    labelKeys: string[];
}
/** Updated contact. */
interface UnlabelContactResponse {
    /** Updated contact. */
    contact?: Contact;
}
interface Sorting {
    /**
     * Field to sort by.
     *
     * Supported properties:
     * `createdDate`, `lastActivity.activityDate`, `primaryInfo.email`, `info.name.first`, `info.name.last`, `info.company`,
     * `info.jobTitle`, `info.birthdate`
     * @maxLength 100
     */
    fieldName?: string;
    /**
     * Sort order.
     * Use `ASC` for ascending order or `DESC` for descending order.
     *
     * Defaults to `ASC`.
     */
    order?: SortOrderWithLiterals;
}
declare enum SortOrder {
    ASC = "ASC",
    DESC = "DESC"
}
/** @enumType */
type SortOrderWithLiterals = SortOrder | 'ASC' | 'DESC';
interface Paging {
    /**
     * Number of items to return. Learn more about pagination in API Query Language([SDK](https://dev.wix.com/docs/sdk/articles/work-with-the-sdk/api-query-language)|[REST](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#paging).
     *
     * Default: `50`. <br>
     * Maximum: `1000`.
     * @max 1000
     */
    limit?: number | null;
    /** Number of items to skip in the current sort order. */
    offset?: number | null;
}
declare enum ContactFieldSet {
    /** name, primaryEmail, primaryPhone */
    BASIC = "BASIC",
    /** name, phones, emails, addresses */
    COMMUNICATION_DETAILS = "COMMUNICATION_DETAILS",
    /** name, primaryInfo(email, phone), extendedFields */
    EXTENDED = "EXTENDED",
    /** Full contact object */
    FULL = "FULL"
}
/** @enumType */
type ContactFieldSetWithLiterals = ContactFieldSet | 'BASIC' | 'COMMUNICATION_DETAILS' | 'EXTENDED' | 'FULL';
interface PagingMetadata {
    /** The number of items returned in this response. */
    count?: number | null;
    /** The offset which was requested. */
    offset?: number | null;
    /** The total number of items that match the query. */
    total?: number | null;
    /** A flag that indicates the server failed to calculate 'total' field. */
    tooManyToCount?: boolean | null;
}
interface QueryContactsRequest {
    /**
     * Plain text search for an exact match.
     *
     * Supported properties:
     * `info.name.first`, `info.name.last`, `info.emails.email`, `info.phones.phone`
     *
     * Max: 100 characters
     * @maxLength 100
     */
    search?: string | null;
    /** Query options. */
    query?: Query;
}
interface Query {
    /**
     * Filter object.
     * See [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language)
     * for more information.
     *
     * For a detailed list of supported filters, see
     * [Supported Filters](https://dev.wix.com/api/rest/contacts/contacts/supported-filters).
     */
    filter?: Record<string, any> | null;
    /**
     * Sorting options.
     * See [Sorting and Paging](https://dev.wix.com/api/rest/getting-started/pagination)
     * for more information.
     *
     * Max: 1 sort object
     * @maxSize 1
     */
    sort?: Sorting[];
    /** Pagination options. */
    paging?: Paging;
    /**
     * List of projected fields to return.
     * If both `fields` and `fieldsets` are sent in the request,
     * the union of both lists is returned.
     * `id` and `revision` are always returned.
     *
     * Supported properties:
     * `source`, `createdDate`, `updatedDate`, `lastActivity`, `primaryInfo`,
     * `info.name`, `info.emails`, `info.phones`, `info.addresses`, `info.company`,
     * `info.jobTitle`, `info.picture`, `info.birthdate`, `info.locale`,
     * `info.labelKeys`, `info.locations`, `info.extendedFields`
     * @maxLength 100
     * @maxSize 100
     */
    fields?: string[];
    /**
     * Predefined sets of fields to return.
     * If both `fields` and `fieldsets` are sent in the request,
     * the union of both lists is returned.
     *
     * - `BASIC`: Returns `id`, `revision`, `primaryInfo`, `info.name`.
     * - `COMMUNICATION_DETAILS`: Returns `id`, `revision`, `primaryInfo`, `info.name`, `info.emails`, `info.phones`, `info.addresses`.
     * - `EXTENDED`: Returns `id`, `revision`, `primaryInfo`, `info.name`, `info.extendedFields`.
     * - `FULL`: Returns all fields.
     *
     * Default: If `fields` is omitted from the request, `FULL`.
     * @maxSize 10
     */
    fieldsets?: ContactFieldSetWithLiterals[];
}
/** List of contacts. */
interface QueryContactsResponse {
    /** List of contacts. */
    contacts?: Contact[];
    /** Details on the paged set of results returned. */
    pagingMetadata?: PagingMetadata;
}
interface GetContactRequest {
    /**
     * ID of the contact to retrieve.
     * @format GUID
     */
    id: string;
    /**
     * List of projected fields to return.
     * If both `fields` and `fieldsets` are sent in the request,
     * the union of both lists is returned.
     * `id` and `revision` are always returned.
     *
     * Supported properties:
     * `source`, `createdDate`, `updatedDate`, `lastActivity`, `primaryInfo`,
     * `info.name`, `info.emails`, `info.phones`, `info.addresses`, `info.company`,
     * `info.jobTitle`, `info.picture`, `info.birthdate`, `info.locale`,
     * `info.labelKeys`, `info.locations`, `info.extendedFields`
     * @maxLength 100
     * @maxSize 100
     */
    fields?: string[];
    /**
     * Predefined sets of fields to return.
     * If both `fields` and `fieldsets` are sent in the request,
     * the union of both lists is returned.
     *
     * - `BASIC`: Returns `id`, `revision`, `primaryInfo`, `info.name`.
     * - `COMMUNICATION_DETAILS`: Returns `id`, `revision`, `primaryInfo`, `info.name`, `info.emails`, `info.phones`, `info.addresses`.
     * - `EXTENDED`: Returns `id`, `revision`, `primaryInfo`, `info.name`, `info.extendedFields`.
     * - `FULL`: Returns all fields.
     *
     * Default: If `fields` is omitted from the request, `FULL`.
     * @maxSize 10
     */
    fieldsets?: ContactFieldSetWithLiterals[];
}
/** The requested contact. */
interface GetContactResponse {
    /** The requested contact. */
    contact?: Contact;
    /** Contact response type. */
    responseType?: GetContactResponseTypeWithLiterals;
}
declare enum GetContactResponseType {
    /** The specified contact was returned. */
    REGULAR = "REGULAR",
    /** Not used. */
    IMPLICIT = "IMPLICIT",
    /** The specified contact was previously merged with another contact and the new contact was returned. */
    MERGED = "MERGED"
}
/** @enumType */
type GetContactResponseTypeWithLiterals = GetContactResponseType | 'REGULAR' | 'IMPLICIT' | 'MERGED';

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function createContact(): __PublicMethodMetaInfo<'POST', {}, CreateContactRequest$1, CreateContactRequest, CreateContactResponse$1, CreateContactResponse>;
declare function updateContact(): __PublicMethodMetaInfo<'PATCH', {
    contactId: string;
}, UpdateContactRequest$1, UpdateContactRequest, UpdateContactResponse$1, UpdateContactResponse>;
declare function mergeContacts(): __PublicMethodMetaInfo<'POST', {
    targetContactId: string;
}, MergeContactsRequest$1, MergeContactsRequest, MergeContactsResponse$1, MergeContactsResponse>;
declare function deleteContact(): __PublicMethodMetaInfo<'DELETE', {
    contactId: string;
}, DeleteContactRequest$1, DeleteContactRequest, DeleteContactResponse$1, DeleteContactResponse>;
declare function labelContact(): __PublicMethodMetaInfo<'POST', {
    contactId: string;
}, LabelContactRequest$1, LabelContactRequest, LabelContactResponse$1, LabelContactResponse>;
declare function unlabelContact(): __PublicMethodMetaInfo<'DELETE', {
    contactId: string;
}, UnlabelContactRequest$1, UnlabelContactRequest, UnlabelContactResponse$1, UnlabelContactResponse>;
declare function queryContacts(): __PublicMethodMetaInfo<'POST', {}, QueryContactsRequest$1, QueryContactsRequest, QueryContactsResponse$1, QueryContactsResponse>;
declare function getContact(): __PublicMethodMetaInfo<'GET', {
    id: string;
}, GetContactRequest$1, GetContactRequest, GetContactResponse$1, GetContactResponse>;

export { type __PublicMethodMetaInfo, createContact, deleteContact, getContact, labelContact, mergeContacts, queryContacts, unlabelContact, updateContact };
