// src/contacts-v4-contact-contacts.http.ts
import { toURLSearchParams } from "@wix/sdk-runtime/rest-modules";
import { transformSDKFloatToRESTFloat } from "@wix/sdk-runtime/transformations/float";
import { transformRESTFloatToSDKFloat } from "@wix/sdk-runtime/transformations/float";
import { transformSDKTimestampToRESTTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformRESTTimestampToSDKTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformSDKFieldMaskToRESTFieldMask } from "@wix/sdk-runtime/transformations/field-mask";
import { transformPaths } from "@wix/sdk-runtime/transformations/transform-paths";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveComWixpressContactsCoreApiV4ContactsServiceV4Url(opts) {
  const domainToMappings = {
    "www._base_domain_": [
      {
        srcPath: "/_api/contacts/v4/contacts",
        destPath: "/v4/contacts"
      },
      {
        srcPath: "/_api/contacts/v4/bulk",
        destPath: "/v4/bulk"
      }
    ],
    "www.wixapis.com": [
      {
        srcPath: "/contacts/v4/contacts",
        destPath: "/v4/contacts"
      },
      {
        srcPath: "/contacts/v4/bulk",
        destPath: "/v4/bulk"
      }
    ],
    "manage._base_domain_": [
      {
        srcPath: "/_api/contacts/v4/contacts",
        destPath: "/v4/contacts"
      },
      {
        srcPath: "/_api/contacts/v4/bulk",
        destPath: "/v4/bulk"
      }
    ],
    "manage.nownia.com": [
      {
        srcPath: "/_api/contacts/v4/contacts",
        destPath: "/v4/contacts"
      },
      {
        srcPath: "/_api/contacts/v4/bulk",
        destPath: "/v4/bulk"
      }
    ],
    _: [
      {
        srcPath: "/_api/contacts/v4/bulk",
        destPath: "/v4/bulk"
      },
      {
        srcPath: "/_api/contacts/v4/contacts",
        destPath: "/v4/contacts"
      }
    ],
    "*.dev.wix-code.com": [
      {
        srcPath: "/_api/contacts/v4/bulk",
        destPath: "/v4/bulk"
      },
      {
        srcPath: "/_api/contacts/v4/contacts",
        destPath: "/v4/contacts"
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_crm_contacts";
function createContact(payload) {
  function __createContact({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKFloatToRESTFloat,
        paths: [
          { path: "info.addresses.items.address.geocode.latitude" },
          { path: "info.addresses.items.address.geocode.longitude" }
        ]
      },
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [{ path: "info.picture.image.urlExpirationDate" }]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.contacts.v4.contact",
      method: "POST",
      methodFqn: "com.wixpress.contacts.core.api.v4.ContactsServiceV4.CreateContact",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressContactsCoreApiV4ContactsServiceV4Url({
        protoPath: "/v4/contacts",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "contact.createdDate" },
            { path: "contact.updatedDate" },
            { path: "contact.lastActivity.activityDate" },
            { path: "contact.lastActivity.date" },
            { path: "contact.picture.urlExpirationDate" },
            { path: "contact.info.picture.image.urlExpirationDate" },
            { path: "contact.memberInfo.signupDate" },
            {
              path: "contact.memberInfo.profileInfo.photo.urlExpirationDate"
            },
            { path: "contact.memberInfo.sessionInfo.lastWebLogin" },
            { path: "contact.memberInfo.sessionInfo.lastMobileLogin" }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            { path: "contact.info.addresses.items.address.geocode.latitude" },
            {
              path: "contact.info.addresses.items.address.geocode.longitude"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __createContact;
}
function updateContact(payload) {
  function __updateContact({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKFieldMaskToRESTFieldMask,
        paths: [{ path: "fieldMask" }]
      },
      {
        transformFn: transformSDKFloatToRESTFloat,
        paths: [
          { path: "info.addresses.items.address.geocode.latitude" },
          { path: "info.addresses.items.address.geocode.longitude" }
        ]
      },
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [{ path: "info.picture.image.urlExpirationDate" }]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.contacts.v4.contact",
      method: "PATCH",
      methodFqn: "com.wixpress.contacts.core.api.v4.ContactsServiceV4.UpdateContact",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressContactsCoreApiV4ContactsServiceV4Url({
        protoPath: "/v4/contacts/{contactId}",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "contact.createdDate" },
            { path: "contact.updatedDate" },
            { path: "contact.lastActivity.activityDate" },
            { path: "contact.lastActivity.date" },
            { path: "contact.picture.urlExpirationDate" },
            { path: "contact.info.picture.image.urlExpirationDate" },
            { path: "contact.memberInfo.signupDate" },
            {
              path: "contact.memberInfo.profileInfo.photo.urlExpirationDate"
            },
            { path: "contact.memberInfo.sessionInfo.lastWebLogin" },
            { path: "contact.memberInfo.sessionInfo.lastMobileLogin" }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            { path: "contact.info.addresses.items.address.geocode.latitude" },
            {
              path: "contact.info.addresses.items.address.geocode.longitude"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __updateContact;
}
function mergeContacts(payload) {
  function __mergeContacts({ host }) {
    const metadata = {
      entityFqdn: "wix.contacts.v4.contact",
      method: "POST",
      methodFqn: "com.wixpress.contacts.core.api.v4.ContactsServiceV4.MergeContacts",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressContactsCoreApiV4ContactsServiceV4Url({
        protoPath: "/v4/contacts/{targetContactId}/merge",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "contact.createdDate" },
            { path: "contact.updatedDate" },
            { path: "contact.lastActivity.activityDate" },
            { path: "contact.lastActivity.date" },
            { path: "contact.picture.urlExpirationDate" },
            { path: "contact.info.picture.image.urlExpirationDate" },
            { path: "contact.memberInfo.signupDate" },
            {
              path: "contact.memberInfo.profileInfo.photo.urlExpirationDate"
            },
            { path: "contact.memberInfo.sessionInfo.lastWebLogin" },
            { path: "contact.memberInfo.sessionInfo.lastMobileLogin" }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            { path: "contact.info.addresses.items.address.geocode.latitude" },
            {
              path: "contact.info.addresses.items.address.geocode.longitude"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __mergeContacts;
}
function deleteContact(payload) {
  function __deleteContact({ host }) {
    const metadata = {
      entityFqdn: "wix.contacts.v4.contact",
      method: "DELETE",
      methodFqn: "com.wixpress.contacts.core.api.v4.ContactsServiceV4.DeleteContact",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressContactsCoreApiV4ContactsServiceV4Url({
        protoPath: "/v4/contacts/{contactId}",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload)
    };
    return metadata;
  }
  return __deleteContact;
}
function labelContact(payload) {
  function __labelContact({ host }) {
    const metadata = {
      entityFqdn: "wix.contacts.v4.contact",
      method: "POST",
      methodFqn: "com.wixpress.contacts.core.api.v4.ContactsServiceV4.LabelContact",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressContactsCoreApiV4ContactsServiceV4Url({
        protoPath: "/v4/contacts/{contactId}/labels",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "contact.createdDate" },
            { path: "contact.updatedDate" },
            { path: "contact.lastActivity.activityDate" },
            { path: "contact.lastActivity.date" },
            { path: "contact.picture.urlExpirationDate" },
            { path: "contact.info.picture.image.urlExpirationDate" },
            { path: "contact.memberInfo.signupDate" },
            {
              path: "contact.memberInfo.profileInfo.photo.urlExpirationDate"
            },
            { path: "contact.memberInfo.sessionInfo.lastWebLogin" },
            { path: "contact.memberInfo.sessionInfo.lastMobileLogin" }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            { path: "contact.info.addresses.items.address.geocode.latitude" },
            {
              path: "contact.info.addresses.items.address.geocode.longitude"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __labelContact;
}
function unlabelContact(payload) {
  function __unlabelContact({ host }) {
    const metadata = {
      entityFqdn: "wix.contacts.v4.contact",
      method: "DELETE",
      methodFqn: "com.wixpress.contacts.core.api.v4.ContactsServiceV4.UnlabelContact",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressContactsCoreApiV4ContactsServiceV4Url({
        protoPath: "/v4/contacts/{contactId}/labels",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "contact.createdDate" },
            { path: "contact.updatedDate" },
            { path: "contact.lastActivity.activityDate" },
            { path: "contact.lastActivity.date" },
            { path: "contact.picture.urlExpirationDate" },
            { path: "contact.info.picture.image.urlExpirationDate" },
            { path: "contact.memberInfo.signupDate" },
            {
              path: "contact.memberInfo.profileInfo.photo.urlExpirationDate"
            },
            { path: "contact.memberInfo.sessionInfo.lastWebLogin" },
            { path: "contact.memberInfo.sessionInfo.lastMobileLogin" }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            { path: "contact.info.addresses.items.address.geocode.latitude" },
            {
              path: "contact.info.addresses.items.address.geocode.longitude"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __unlabelContact;
}
function queryContacts(payload) {
  function __queryContacts({ host }) {
    const metadata = {
      entityFqdn: "wix.contacts.v4.contact",
      method: "POST",
      methodFqn: "com.wixpress.contacts.core.api.v4.ContactsServiceV4.QueryContacts",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressContactsCoreApiV4ContactsServiceV4Url({
        protoPath: "/v4/contacts/query",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "contacts.createdDate" },
            { path: "contacts.updatedDate" },
            { path: "contacts.lastActivity.activityDate" },
            { path: "contacts.lastActivity.date" },
            { path: "contacts.picture.urlExpirationDate" },
            { path: "contacts.info.picture.image.urlExpirationDate" },
            { path: "contacts.memberInfo.signupDate" },
            {
              path: "contacts.memberInfo.profileInfo.photo.urlExpirationDate"
            },
            { path: "contacts.memberInfo.sessionInfo.lastWebLogin" },
            { path: "contacts.memberInfo.sessionInfo.lastMobileLogin" }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            {
              path: "contacts.info.addresses.items.address.geocode.latitude"
            },
            {
              path: "contacts.info.addresses.items.address.geocode.longitude"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __queryContacts;
}
function getContact(payload) {
  function __getContact({ host }) {
    const metadata = {
      entityFqdn: "wix.contacts.v4.contact",
      method: "GET",
      methodFqn: "com.wixpress.contacts.core.api.v4.ContactsServiceV4.GetContact",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressContactsCoreApiV4ContactsServiceV4Url({
        protoPath: "/v4/contacts/{id}",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "contact.createdDate" },
            { path: "contact.updatedDate" },
            { path: "contact.lastActivity.activityDate" },
            { path: "contact.lastActivity.date" },
            { path: "contact.picture.urlExpirationDate" },
            { path: "contact.info.picture.image.urlExpirationDate" },
            { path: "contact.memberInfo.signupDate" },
            {
              path: "contact.memberInfo.profileInfo.photo.urlExpirationDate"
            },
            { path: "contact.memberInfo.sessionInfo.lastWebLogin" },
            { path: "contact.memberInfo.sessionInfo.lastMobileLogin" }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            { path: "contact.info.addresses.items.address.geocode.latitude" },
            {
              path: "contact.info.addresses.items.address.geocode.longitude"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __getContact;
}

// src/contacts-v4-contact-contacts.meta.ts
function createContact2() {
  const payload = {};
  const getRequestOptions = createContact(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v4/contacts",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function updateContact2() {
  const payload = { contactId: ":contactId" };
  const getRequestOptions = updateContact(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "PATCH",
    path: "/v4/contacts/{contactId}",
    pathParams: { contactId: "contactId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function mergeContacts2() {
  const payload = { targetContactId: ":targetContactId" };
  const getRequestOptions = mergeContacts(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v4/contacts/{targetContactId}/merge",
    pathParams: { targetContactId: "targetContactId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function deleteContact2() {
  const payload = { contactId: ":contactId" };
  const getRequestOptions = deleteContact(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "DELETE",
    path: "/v4/contacts/{contactId}",
    pathParams: { contactId: "contactId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function labelContact2() {
  const payload = { contactId: ":contactId" };
  const getRequestOptions = labelContact(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v4/contacts/{contactId}/labels",
    pathParams: { contactId: "contactId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function unlabelContact2() {
  const payload = { contactId: ":contactId" };
  const getRequestOptions = unlabelContact(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "DELETE",
    path: "/v4/contacts/{contactId}/labels",
    pathParams: { contactId: "contactId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function queryContacts2() {
  const payload = {};
  const getRequestOptions = queryContacts(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v4/contacts/query",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function getContact2() {
  const payload = { id: ":id" };
  const getRequestOptions = getContact(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "GET",
    path: "/v4/contacts/{id}",
    pathParams: { id: "id" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
export {
  createContact2 as createContact,
  deleteContact2 as deleteContact,
  getContact2 as getContact,
  labelContact2 as labelContact,
  mergeContacts2 as mergeContacts,
  queryContacts2 as queryContacts,
  unlabelContact2 as unlabelContact,
  updateContact2 as updateContact
};
//# sourceMappingURL=meta.mjs.map